"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.DOMParserFixed = void 0;
const xmldom = require('../xmldom/dom-parser');
class DOMParserFixed {
    constructor() {
    }
    parseFromString(source, mimeType) {
        let domOptions = {
            locator: {},
            errorHandler: {
                warning: function (error) {
                    if (mimeType !== 'text/html') {
                        let msg = error;
                        if (domOptions.error == null) {
                            domOptions.error = { level: "warning", message: error };
                        }
                        throw msg;
                    }
                },
                error: function (error) {
                    let msg = error;
                    if (domOptions.error == null) {
                        domOptions.error = { level: "error", message: error };
                    }
                    throw msg;
                },
                fatalError: function (error) {
                    let msg = error;
                    if (domOptions.error == null) {
                        domOptions.error = { level: "fatalError", message: error };
                    }
                    throw msg;
                }
            }
        };
        let domParser = new xmldom.DOMParser(domOptions);
        try {
            return domParser.parseFromString(source, mimeType);
        }
        catch (err) {
            if (domOptions.error == null) {
                domOptions.error = { level: "exception", message: err };
            }
            return DOMParserFixed._createParseErrorDoc(domOptions, source);
        }
    }
    static _createParseErrorDoc(domOptions, source) {
        let description = domOptions.error.message;
        let index0 = description.indexOf(']\t');
        if (index0 >= 0) {
            let index1 = description.indexOf('\n@');
            if (index1 >= index0) {
                description = description.substr(index0 + 2, index1 - index0 - 3);
                description = `${description} at line ${domOptions.locator.lineNumber}, column ${domOptions.locator.columnNumber}`;
            }
        }
        let domImplementation = new xmldom.DOMImplementation();
        let xmlDoc = domImplementation.createDocument(null, null, null);
        let parseErrorElt = xmlDoc.createElementNS('http://www.mozilla.org/newlayout/xml/parsererror.xml', 'parsererror');
        parseErrorElt.textContent = description;
        xmlDoc.appendChild(parseErrorElt);
        if (domOptions.locator && source && source.length) {
            let line = 1;
            let index0 = 0;
            let index1 = source.indexOf('\n', index0);
            while ((index1 >= 0) && (line < domOptions.locator.lineNumber)) {
                index0 = index1 + 1;
                index1 = source.indexOf('\n', index0);
                ++line;
            }
            let sourcetTextElt = xmlDoc.createElement('sourcetext');
            index0 += domOptions.locator.columnNumber;
            if (index1 < 0) {
                index1 = index0 + 20;
            }
            else if (source[index1 - 1] === '\r') {
                --index1;
            }
            sourcetTextElt.textContent = source.substr(index0, index1 - index0);
            parseErrorElt.appendChild(sourcetTextElt);
        }
        return xmlDoc;
    }
}
exports.DOMParserFixed = DOMParserFixed;
//# sourceMappingURL=domParser.js.map